# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`zfs`](#zfs): Installs basic ZFS kernel and userland support.
* [`zfs::config`](#zfsconfig)
* [`zfs::install`](#zfsinstall)
* [`zfs::service`](#zfsservice)
* [`zfs::zed`](#zfszed): Installs the ZFS Event Daemon.
* [`zfs::zed::config`](#zfszedconfig)
* [`zfs::zed::install`](#zfszedinstall)
* [`zfs::zed::service`](#zfszedservice)

### Defined types

* [`zfs::scrub`](#zfsscrub): Set up a zpool scrub cron entry.
* [`zfs::zed::zedlet`](#zfszedzedlet): Enables either a packaged or custom ZFS Event Daemon "zedlet".  Not specifying either `$content` or `$source` results in the zedlet being sym

### Tasks

* [`scrub`](#scrub): Allows you to initiate the scrub of a zpool

## Classes

### <a name="zfs"></a>`zfs`

Installs basic ZFS kernel and userland support.

* **See also**
  * puppet_classes::zfs::zed
    * zfs::zed
  * puppet_defined_types::zfs::scrub
    * zfs::scrub

#### Examples

##### Declaring the class

```puppet
include zfs
```

##### Tuning the ZFS ARC

```puppet
class { 'zfs':
  zfs_arc_max => to_bytes('256 M'),
  zfs_arc_min => to_bytes('128 M'),
}
```

#### Parameters

The following parameters are available in the `zfs` class:

* [`conf_dir`](#conf_dir)
* [`kmod_type`](#kmod_type)
* [`manage_repo`](#manage_repo)
* [`package_name`](#package_name)
* [`service_manage`](#service_manage)
* [`zfs_arc_max`](#zfs_arc_max)
* [`zfs_arc_min`](#zfs_arc_min)

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`

Top-level configuration directory, usually `/etc/zfs`.

##### <a name="kmod_type"></a>`kmod_type`

Data type: `Enum['dkms', 'kabi']`

Whether to use DKMS kernel packages or ones built to match
the running kernel (only applies to RHEL platforms).

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Boolean`

Whether to setup and manage external package repositories.

##### <a name="package_name"></a>`package_name`

Data type: `Variant[String, Array[String, 1]]`

The name of the top-level metapackage that installs ZFS
support.

##### <a name="service_manage"></a>`service_manage`

Data type: `Boolean`

Whether to manage the various ZFS services.

##### <a name="zfs_arc_max"></a>`zfs_arc_max`

Data type: `Optional[Integer[0]]`

Maximum size of the ARC in bytes.

##### <a name="zfs_arc_min"></a>`zfs_arc_min`

Data type: `Optional[Integer[0]]`

Minimum size of the ARC in bytes.

### <a name="zfsconfig"></a>`zfs::config`

The zfs::config class.

### <a name="zfsinstall"></a>`zfs::install`

The zfs::install class.

### <a name="zfsservice"></a>`zfs::service`

The zfs::service class.

### <a name="zfszed"></a>`zfs::zed`

Installs the ZFS Event Daemon.

* **Since** 2.0.0

* **See also**
  * puppet_classes::zfs
    * zfs
  * puppet_defined_types::zfs::zed::zedlet
    * zfs::zed::zedlet

#### Examples

##### Declaring the class

```puppet
include zfs
include zfs::zed
```

#### Parameters

The following parameters are available in the `zfs::zed` class:

* [`conf_dir`](#conf_dir)
* [`debug_log`](#debug_log)
* [`email_addrs`](#email_addrs)
* [`email_opts`](#email_opts)
* [`email_prog`](#email_prog)
* [`lock_dir`](#lock_dir)
* [`notify_interval_secs`](#notify_interval_secs)
* [`notify_verbose`](#notify_verbose)
* [`package_name`](#package_name)
* [`pushbullet_access_token`](#pushbullet_access_token)
* [`pushbullet_channel_tag`](#pushbullet_channel_tag)
* [`run_dir`](#run_dir)
* [`service_manage`](#service_manage)
* [`service_name`](#service_name)
* [`spare_on_checksum_errors`](#spare_on_checksum_errors)
* [`spare_on_io_errors`](#spare_on_io_errors)
* [`syslog_priority`](#syslog_priority)
* [`syslog_tag`](#syslog_tag)
* [`use_enclosure_leds`](#use_enclosure_leds)
* [`zedlet_dir`](#zedlet_dir)
* [`zedlets`](#zedlets)

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`

Configuration directory, usually `${zfs::conf_dir}/zed.d`.

##### <a name="debug_log"></a>`debug_log`

Data type: `Optional[Stdlib::Absolutepath]`



##### <a name="email_addrs"></a>`email_addrs`

Data type: `Optional[Array[String, 1]]`



##### <a name="email_opts"></a>`email_opts`

Data type: `Optional[String]`



##### <a name="email_prog"></a>`email_prog`

Data type: `Optional[String]`



##### <a name="lock_dir"></a>`lock_dir`

Data type: `Optional[Stdlib::Absolutepath]`



##### <a name="notify_interval_secs"></a>`notify_interval_secs`

Data type: `Optional[Integer[0]]`



##### <a name="notify_verbose"></a>`notify_verbose`

Data type: `Optional[Boolean]`



##### <a name="package_name"></a>`package_name`

Data type: `Optional[String]`

The name of the package to install if not installed
already by the ZFS class.

##### <a name="pushbullet_access_token"></a>`pushbullet_access_token`

Data type: `Optional[String]`



##### <a name="pushbullet_channel_tag"></a>`pushbullet_channel_tag`

Data type: `Optional[String]`



##### <a name="run_dir"></a>`run_dir`

Data type: `Optional[Stdlib::Absolutepath]`



##### <a name="service_manage"></a>`service_manage`

Data type: `Boolean`

Whether to manage the service.

##### <a name="service_name"></a>`service_name`

Data type: `String`

Name of the service.

##### <a name="spare_on_checksum_errors"></a>`spare_on_checksum_errors`

Data type: `Optional[Integer[1]]`



##### <a name="spare_on_io_errors"></a>`spare_on_io_errors`

Data type: `Optional[Integer[1]]`



##### <a name="syslog_priority"></a>`syslog_priority`

Data type: `Optional[String]`



##### <a name="syslog_tag"></a>`syslog_tag`

Data type: `Optional[String]`



##### <a name="use_enclosure_leds"></a>`use_enclosure_leds`

Data type: `Optional[Boolean]`



##### <a name="zedlet_dir"></a>`zedlet_dir`

Data type: `Stdlib::Absolutepath`

Path to package-provided zedlets.

##### <a name="zedlets"></a>`zedlets`

Data type: `Hash[String, Hash]`

Hash of zedlet resources to create.

### <a name="zfszedconfig"></a>`zfs::zed::config`

The zfs::zed::config class.

### <a name="zfszedinstall"></a>`zfs::zed::install`

The zfs::zed::install class.

### <a name="zfszedservice"></a>`zfs::zed::service`

The zfs::zed::service class.

## Defined types

### <a name="zfsscrub"></a>`zfs::scrub`

Set up a zpool scrub cron entry.

* **Since** 2.2.0

* **See also**
  * puppet_classes::zfs
    * zfs

#### Examples

##### Scrub a zpool once a month

```puppet
include zfs

zfs::scrub { 'test':
  hour     => '1',
  minute   => '0',
  month    => '*',
  monthday => '1',
  weekday  => '*',
}
```

#### Parameters

The following parameters are available in the `zfs::scrub` defined type:

* [`zpool`](#zpool)
* [`hour`](#hour)
* [`minute`](#minute)
* [`month`](#month)
* [`monthday`](#monthday)
* [`weekday`](#weekday)
* [`user`](#user)

##### <a name="zpool"></a>`zpool`

Data type: `String`

The name of the zpool.

Default value: `$title`

##### <a name="hour"></a>`hour`

Data type: `Any`

See the `cron` resource type.

##### <a name="minute"></a>`minute`

Data type: `Any`

See the `cron` resource type.

##### <a name="month"></a>`month`

Data type: `Any`

See the `cron` resource type.

##### <a name="monthday"></a>`monthday`

Data type: `Any`

See the `cron` resource type.

##### <a name="weekday"></a>`weekday`

Data type: `Any`

See the `cron` resource type.

##### <a name="user"></a>`user`

Data type: `String`

See the `cron` resource type.

Default value: `'root'`

### <a name="zfszedzedlet"></a>`zfs::zed::zedlet`

Enables either a packaged or custom ZFS Event Daemon "zedlet".

Not specifying either `$content` or `$source` results in the zedlet being
symlinked from the "installed zedlets" directory.

* **Since** 2.0.0

* **See also**
  * puppet_classes::zfs::zed
    * zfs::zed

#### Examples

##### Enabling a packaged zedlet

```puppet
zfs::zed::zedlet { 'scrub.finish-notify.sh': }
```

##### Enabling a custom zedlet

```puppet
zfs::zed::zedlet { 'scrub.finish-notify.sh':
  source => 'puppet:///example/scrub.finish-notify.sh',
}
```

#### Parameters

The following parameters are available in the `zfs::zed::zedlet` defined type:

* [`content`](#content)
* [`source`](#source)
* [`zedlet`](#zedlet)

##### <a name="content"></a>`content`

Data type: `Optional[String]`

Content of custom zedlet

Default value: ``undef``

##### <a name="source"></a>`source`

Data type: `Optional[String]`

Source of custom zedlet

Default value: ``undef``

##### <a name="zedlet"></a>`zedlet`

Data type: `String`

The filename for the zedlet

Default value: `$title`

## Tasks

### <a name="scrub"></a>`scrub`

Allows you to initiate the scrub of a zpool

**Supports noop?** false

#### Parameters

##### `zpool`

Data type: `String[1]`

Name of the zpool

